Module moore_common::source
[−]
[src]
A global source file table that assigns an opaque ID to each processed source file. This helps keeping the source location lean and allow for simple querying of information.
Structs
| Location |
A single location within a source file, expressed as a byte offset. |
| Source | |
| SourceManager |
A manager for source files and their assigned IDs. |
| Span |
A span of locations within a source file, expressed as a half-open interval
of bytes |
| Spanned |
A wrapper that associates a span with a value. |
Constants
| INVALID_LOCATION | |
| INVALID_SOURCE | |
| INVALID_SPAN |
Traits
| SourceContent | |
| SourceFile |
Functions
| get_source_manager |
Get the global source manager. |
Type Definitions
| CharIter |
An iterator that yields the characters from an input file together with the byte positions within the stream. |