Struct moore_common::source::Location
[−]
[src]
pub struct Location {
pub source: Source,
pub offset: usize,
}A single location within a source file, expressed as a byte offset.
Fields
source: Source
offset: usize
Methods
impl Location[src]
fn new(source: Source, offset: usize) -> Location[src]
Create a new location.
fn iter<'a>(self, content: &'a Rc<SourceContent>) -> Box<CharIter<'a>>[src]
Obtain an iterator into the source file at this location.